CREATE TABLE IF NOT EXISTS `alarm_comment`
(
    `id`          varchar(80) NOT NULL COMMENT '主键',
    `record_id`   varchar(40) NOT NULL DEFAULT '' COMMENT '报警记录id',
    `content`     text        NOT NULL COMMENT '批注内容',
    `create_user` varchar(32) NOT NULL COMMENT '创建人',
    `project_id`  varchar(50)          DEFAULT NULL COMMENT '项目id',
    `group_code`  varchar(50)          DEFAULT NULL COMMENT '集团编码',
    `create_time` timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `update_user` varchar(32)          DEFAULT NULL COMMENT '更新人',
    `valid`       int(11)              DEFAULT '1' COMMENT '删除标记 1:true,0:false',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='报警批注';

CREATE TABLE IF NOT EXISTS `alarm_config`
(
    `id`           varchar(40) NOT NULL COMMENT '主键',
    `obj_id`       varchar(50) NOT NULL COMMENT '对象id',
    `class_code`   varchar(50)          DEFAULT NULL COMMENT '对象类型编码',
    `project_id`   varchar(50)          DEFAULT NULL COMMENT '项目id',
    `group_code`   varchar(50)          DEFAULT NULL COMMENT '集团编码',
    `item_code`    varchar(40) NOT NULL COMMENT '报警条目编码',
    `target_id`    varchar(50)          DEFAULT NULL COMMENT '报警匹配条件id',
    `category`     varchar(10)          DEFAULT NULL COMMENT '报警分类',
    `level`        varchar(10) NOT NULL COMMENT '严重程度',
    `remark`       varchar(500)         DEFAULT NULL COMMENT '备注',
    `condition`    json                 DEFAULT NULL COMMENT '触发条件',
    `open`         int(11)              DEFAULT NULL COMMENT '屏蔽状态 1-open、0- 屏蔽',
    `concern`      int(11)              DEFAULT NULL COMMENT '是否重点关注',
    `user_defined` int(11)              DEFAULT NULL COMMENT '是否自定义',
    `create_user`  varchar(80)          DEFAULT NULL COMMENT '创建用户',
    `create_time`  timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_user`  varchar(80)          DEFAULT NULL COMMENT '更新用户',
    `update_time`  timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `valid`        int(11)     NOT NULL DEFAULT '1' COMMENT '删除标记 1:true,0:false',
    PRIMARY KEY (`id`),
    KEY `index2` (`obj_id`),
    KEY `index3` (`item_code`),
    KEY `index4` (`class_code`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='报警定义';

CREATE TABLE IF NOT EXISTS `alarm_item`
(
    `id`          varchar(40) NOT NULL COMMENT '主键',
    `code`        varchar(40) NOT NULL COMMENT '报警条目编码',
    `name`        varchar(50) NOT NULL DEFAULT '' COMMENT '报警条目名称',
    `category`    varchar(10)          DEFAULT NULL COMMENT '报警分类',
    `level`       varchar(10) NOT NULL COMMENT '严重程度',
    `remark`      varchar(500)         DEFAULT NULL COMMENT '备注',
    `condition`   json                 DEFAULT NULL COMMENT '触发条件',
    `deal_fun`    varchar(40)          DEFAULT NULL COMMENT '处理算法',
    `create_user` varchar(80)          DEFAULT NULL COMMENT '创建用户',
    `project_id`  varchar(50)          DEFAULT '0' COMMENT '项目id，0代表通用',
    `group_code`  varchar(50)          DEFAULT '0' COMMENT '集团编码，0代表通用',
    `create_time` timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_user` varchar(80)          DEFAULT NULL COMMENT '更新用户',
    `update_time` timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `valid`       int(11)              DEFAULT '1' COMMENT '删除标记 1:true,0:false',
    `app_id`      varchar(50)          DEFAULT NULL COMMENT '应用id',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='报警条目';

CREATE TABLE IF NOT EXISTS `alarm_log`
(
    `id`          varchar(80) NOT NULL COMMENT '主键',
    `record_id`   varchar(40) NOT NULL DEFAULT '' COMMENT '报警记录id',
    `type`        varchar(10) NOT NULL DEFAULT '' COMMENT '操作类型（报警状态、报警性质、报警处理方式、报警处理状态）',
    `nature`      int(11)              DEFAULT NULL COMMENT '报警性质',
    `before`      int(11)              DEFAULT NULL COMMENT '修改前报警记录的状态',
    `after`       int(11)              DEFAULT NULL COMMENT '修改后报警记录的状态',
    `remark`      json                 DEFAULT NULL COMMENT '备注',
    `project_id`  varchar(50)          DEFAULT '' COMMENT '项目id',
    `group_code`  varchar(50)          DEFAULT NULL COMMENT '集团编码',
    `create_time` timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `valid`       int(11)              DEFAULT '1' COMMENT '删除标记 1:true,0:false',
    `create_user` varchar(50)          DEFAULT NULL COMMENT '创建人',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='报警日志';

CREATE TABLE IF NOT EXISTS `alarm_record`
(
    `id`                varchar(50) NOT NULL DEFAULT '' COMMENT '主键',
    `item_code`         varchar(40) NOT NULL COMMENT '报警条目编码',
    `project_id`        varchar(50) NOT NULL DEFAULT '' COMMENT '项目id',
    `obj_id`            varchar(50) NOT NULL DEFAULT '' COMMENT '对象id',
    `class_code`        varchar(50)          DEFAULT NULL COMMENT '对象类型编码',
    `level`             varchar(10) NOT NULL COMMENT '严重程度',
    `remark`            text COMMENT '报警描述',
    `create_user`       varchar(80)          DEFAULT NULL COMMENT '创建用户',
    `create_time`       timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_user`       varchar(80)          DEFAULT NULL COMMENT '更新用户',
    `update_time`       timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `valid`             int(11)     NOT NULL DEFAULT '1' COMMENT '删除标记 1:true,0:false',
    `name`              varchar(200)         DEFAULT NULL COMMENT '报警名称',
    `category`          varchar(80)          DEFAULT NULL COMMENT '报警分类',
    `concern`           int(11)              DEFAULT NULL COMMENT '是否重点关注',
    `state`             int(2)               DEFAULT NULL COMMENT '报警状态',
    `effect_start_time` timestamp   NULL     DEFAULT NULL COMMENT '有效期开始时间',
    `effect_end_time`   timestamp   NULL     DEFAULT NULL COMMENT '有效期结束时间',
    `nature`            int(11)              DEFAULT NULL COMMENT '报警性质',
    `treat_mode`        int(11)              DEFAULT NULL COMMENT '处理方式',
    `treat_state`       int(11)              DEFAULT '1' COMMENT '处理状态',
    `group_code`        varchar(50)          DEFAULT NULL COMMENT '集团编码',
    `condition`         json                 DEFAULT NULL COMMENT '触发和恢复条件',
    `trigger_info`      json                 DEFAULT NULL COMMENT '触发值信息',
    `end_info`          json                 DEFAULT NULL COMMENT '恢复值信息',
    `trigger_time`      timestamp   NULL     DEFAULT NULL COMMENT '报警触发时间',
    `end_time`          timestamp   NULL     DEFAULT NULL COMMENT '恢复时间',
    `order_id`          varchar(50)          DEFAULT NULL COMMENT '工单id',
    `order_state`       varchar(10)          DEFAULT NULL COMMENT '工单状态',
    `supplement`        json                 DEFAULT NULL COMMENT '补充说明',
    `target_id`         varchar(100)         DEFAULT NULL COMMENT '匹配规则id',
    PRIMARY KEY (`id`),
    KEY `index2` (`item_code`),
    KEY `index3` (`obj_id`),
    KEY `index4` (`trigger_time`),
    KEY `index5` (`class_code`),
    KEY `project_id` (`project_id`) USING BTREE,
    KEY `state` (`state`) USING BTREE,
    KEY `treat_state` (`treat_state`) USING BTREE,
    KEY `trigger_time` (`trigger_time`) USING BTREE,
    KEY `group_code` (`group_code`) USING BTREE,
    KEY `category` (`category`) USING BTREE,
    KEY `valid` (`valid`) USING BTREE
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='报警记录';


CREATE TABLE IF NOT EXISTS `alarm_target`
(
    `id`          varchar(40) NOT NULL COMMENT '主键',
    `item_code`   varchar(40)          DEFAULT NULL COMMENT '报警条目id',
    `class_code`  varchar(40)          DEFAULT NULL COMMENT '对象类型',
    `condition`   json                 DEFAULT NULL COMMENT '触发条件',
    `level`       varchar(10)          DEFAULT NULL COMMENT '报警等级',
    `concern`     int(11)     NOT NULL DEFAULT '0' COMMENT '是否重点关注',
    `open`        int(11)     NOT NULL DEFAULT '0' COMMENT '屏蔽状态（0：不屏蔽，1：屏蔽）',
    `create_user` varchar(80)          DEFAULT NULL COMMENT '创建用户',
    `create_time` timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_user` varchar(80)          DEFAULT NULL COMMENT '更新用户',
    `update_time` timestamp   NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `valid`       int(11)     NOT NULL DEFAULT '1' COMMENT '删除标记 1:true,0:false',
    `project_id`  varchar(50)          DEFAULT NULL COMMENT '项目id',
    `group_code`  varchar(50)          DEFAULT NULL COMMENT '集团编码',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='报警匹配条件';

